@@ -52,7 +52,6 @@ my %platform_vars = (
     bat => {
         windows => '.bat',
         default => '',
-
     },
     exe => {
         windows => '.exe',
@@ -550,7 +549,13 @@ sub configure_commands {
         $config->{cp}     = 'cp --';
 
         # Symlinking should override destination.
-        $config->{ln_s}   = 'ln -nfs --';
+        $config->{ln_s}   = $self->is_aix
+                            ? '$(PERL5) ' 
+                                . $self->shell_quote_filename(
+                                    File::Spec->catfile(
+                                        $self->cfg('base_dir'),
+                                        'tools', 'build', 'ln_s.pl'))
+                            : 'ln -nfs --';
         $config->{rm_f}   = 'rm -f --';
         $config->{rm_rf}  = 'rm -rf --';
         $config->{rm_l}   = 'rm -f --';
@@ -847,6 +852,11 @@ sub is_bsd {
     return $bsd;
 }
 
+sub is_aix {
+    state $aix = $^O =~ /aix/;
+    return $aix;
+}
+
 sub isa_unix {
 
     # The following is a partial OS list taken from Perl::OSType module,
@@ -1425,6 +1435,14 @@ sub c_escape_string {
     return $str;
 }
 
+sub sq_escape_string {
+    my $self = shift;
+    my $str  = shift;
+    $str =~ s{\\}{\\\\}sg;
+    $str =~ s{'}{\\'}sg;
+    return $str;
+}
+
 #########################################################
 ### Non-method subs
 #########################################################
